pub struct TaskMonitorCoreBuilder { /* private fields */ }Expand description
Provides an interface for constructing a TaskMonitorCore with specialized configuration
parameters.
use std::time::Duration;
use tokio_metrics::TaskMonitorCoreBuilder;
static MONITOR: tokio_metrics::TaskMonitorCore = TaskMonitorCoreBuilder::new()
.with_slow_poll_threshold(Duration::from_micros(100))
.build();Implementations
Sourceimpl TaskMonitorCoreBuilder
impl TaskMonitorCoreBuilder
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new TaskMonitorCoreBuilder.
Sourcepub const fn with_slow_poll_threshold(self, threshold: Duration) -> Self
pub const fn with_slow_poll_threshold(self, threshold: Duration) -> Self
Specifies the threshold at which polls are considered ‘slow’.
Sourcepub const fn with_long_delay_threshold(self, threshold: Duration) -> Self
pub const fn with_long_delay_threshold(self, threshold: Duration) -> Self
Specifies the threshold at which schedules are considered ‘long’.
Sourcepub const fn build(self) -> TaskMonitorCore
pub const fn build(self) -> TaskMonitorCore
Consume the builder, producing a TaskMonitorCore.